
class tds:
  def __init__(self):
    self.td_seq_setup_6_price = 0
    self.td_seq_setup_7_price = 0
    self.td_seq_setup_8_price = 0
    self.lower_price_of_9 = 0
    self.sell_lower_price_of_9 = 0
 
 
    self.td_seq_buy_setup = 0
    self.td_seq_sell_setup = 0
 
 
    self.local_price_history = [0,0,0,0,0,0,0,0,0]
    self.td_seq_buy = False
    self.td_seq_sell = False
   
  def price_update(self, price):
    if len(self.local_price_history) == 9:
      del self.local_price_history[0]
  
  
    self.local_price_history.append(price)

    if self.td_seq_buy_setup == 9:

          self.td_seq_buy_setup = 0
          self.td_seq_buy = False
    elif self.td_seq_sell_setup == 9:
          self.td_seq_sell_setup = 0
          self.td_seq_sell = False


    if not self.local_price_history[5] == 0:

      if price > self.local_price_history[5]:


        self.td_seq_buy_setup += 1
        self.td_seq_sell_setup = 0

        if self.td_seq_buy_setup == 6:
          self.td_seq_setup_6_price = price
        if self.td_seq_buy_setup == 7:
          self.td_seq_setup_7_price = price
        if self.td_seq_buy_setup == 8:
          self.td_seq_setup_8_price = price
  
        if self.td_seq_buy_setup == 9:
          self.lower_price_of_9 = price
          if self.lower_price_of_9 > self.td_seq_setup_6_price and self.lower_price_of_9 > self.td_seq_setup_7_price or self.td_seq_setup_8_price > self.td_seq_setup_6_price and self.td_seq_setup_8_price > self.td_seq_setup_7_price:
            self.td_seq_buy = True

      elif price < self.local_price_history[5] : #SELL Setup

        self.td_seq_sell_setup += 1
        self.td_seq_buy_setup = 0
        if self.td_seq_sell_setup == 6:
          self.td_seq_sell_setup_6_price = price
        if self.td_seq_sell_setup == 7:
          self.td_seq_sell_setup_7_price = price
        if self.td_seq_sell_setup == 8:
          self.td_seq_sell_setup_8_price = price
  
        if self.td_seq_sell_setup == 9:
          self.sell_lower_price_of_9 = price
          if self.sell_lower_price_of_9 < self.td_seq_setup_6_price and self.sell_lower_price_of_9 < self.td_seq_setup_7_price or self.td_seq_setup_8_price < self.td_seq_setup_6_price and self.td_seq_setup_8_price < self.td_seq_setup_7_price:
            self.td_seq_sell = True
          
  
  
      elif price == self.local_price_history[5]:
        self.td_seq_buy_setup = 0
        self.td_seq_sell_setup = 0
  
    
    return self.td_seq_buy_setup, self.td_seq_sell_setup, self.td_seq_buy, self.td_seq_sell


TDS = tds()


from setuptools import setup


setup(name='td_sequential_calculator',
version='0.1.0',
description="""A library to calculating td sequental.""",
long_description="""
# TD Sequential Calculator
A library to calculating td sequental.
# Install
```
pip3 install td-sequential-calculator
```
# Using
## In another script
```python
from td_sequential_calculator import TDS
for i in range(13):
  buy_setup, sell_setup, buy, sell = TDS.price_update(i)
  print(f"Buy setup: {buy_setup}")
  print(f"Sell setup: {sell_setup}")
  if buy:
    print("BUY")
  elif sell:
    print("SELL")
```
""",
long_description_content_type='text/markdown',
url='https://github.com/onuratakan/td_sequential_calculator',
author='Onur Atakan ULUSOY',
author_email='atadogan06@gmail.com',
license='MIT',
packages=["td_sequential_calculator"],
package_dir={'':'src'},
python_requires=">= 3",
zip_safe=False)